@@ -121,10 +121,10 @@ from plaid.model.bank_transfers_events_update_webhook import BankTransfersEvents
 from plaid.model.categories_get_response import CategoriesGetResponse
 from plaid.model.category import Category
 from plaid.model.cause import Cause
+from plaid.model.cause_all_of import CauseAllOf
 from plaid.model.client_provided_enhanced_transaction import ClientProvidedEnhancedTransaction
 from plaid.model.client_provided_raw_transaction import ClientProvidedRawTransaction
 from plaid.model.connected_application import ConnectedApplication
-from plaid.model.connected_application_status import ConnectedApplicationStatus
 from plaid.model.consent_payment_idempotency_key import ConsentPaymentIdempotencyKey
 from plaid.model.country_code import CountryCode
 from plaid.model.credit_account_subtype import CreditAccountSubtype
@@ -148,7 +148,18 @@ from plaid.model.credit_bank_income_warning import CreditBankIncomeWarning
 from plaid.model.credit_bank_income_warning_code import CreditBankIncomeWarningCode
 from plaid.model.credit_bank_income_warning_type import CreditBankIncomeWarningType
 from plaid.model.credit_card_liability import CreditCardLiability
+from plaid.model.credit_document_metadata import CreditDocumentMetadata
+from plaid.model.credit_employer_verification import CreditEmployerVerification
+from plaid.model.credit_employment_get_request import CreditEmploymentGetRequest
+from plaid.model.credit_employment_get_response import CreditEmploymentGetResponse
+from plaid.model.credit_employment_verification import CreditEmploymentVerification
 from plaid.model.credit_filter import CreditFilter
+from plaid.model.credit_payroll_income_get_request import CreditPayrollIncomeGetRequest
+from plaid.model.credit_payroll_income_get_response import CreditPayrollIncomeGetResponse
+from plaid.model.credit_payroll_income_precheck_request import CreditPayrollIncomePrecheckRequest
+from plaid.model.credit_payroll_income_precheck_response import CreditPayrollIncomePrecheckResponse
+from plaid.model.credit_platform_ids import CreditPlatformIds
+from plaid.model.credit_w2 import CreditW2
 from plaid.model.customer_initiated_return_risk import CustomerInitiatedReturnRisk
 from plaid.model.customer_initiated_risk_tier import CustomerInitiatedRiskTier
 from plaid.model.deductions import Deductions
@@ -356,6 +367,22 @@ from plaid.model.pay import Pay
 from plaid.model.pay_frequency import PayFrequency
 from plaid.model.pay_frequency_value import PayFrequencyValue
 from plaid.model.pay_period_details import PayPeriodDetails
+from plaid.model.pay_stub import PayStub
+from plaid.model.pay_stub_address import PayStubAddress
+from plaid.model.pay_stub_deductions import PayStubDeductions
+from plaid.model.pay_stub_deductions_breakdown import PayStubDeductionsBreakdown
+from plaid.model.pay_stub_deductions_total import PayStubDeductionsTotal
+from plaid.model.pay_stub_distribution_breakdown import PayStubDistributionBreakdown
+from plaid.model.pay_stub_earnings import PayStubEarnings
+from plaid.model.pay_stub_earnings_breakdown import PayStubEarningsBreakdown
+from plaid.model.pay_stub_earnings_total import PayStubEarningsTotal
+from plaid.model.pay_stub_employee import PayStubEmployee
+from plaid.model.pay_stub_employer import PayStubEmployer
+from plaid.model.pay_stub_net_pay import PayStubNetPay
+from plaid.model.pay_stub_pay_period_details import PayStubPayPeriodDetails
+from plaid.model.pay_stub_taxpayer_id import PayStubTaxpayerID
+from plaid.model.pay_stub_verification import PayStubVerification
+from plaid.model.pay_stub_verification_attribute import PayStubVerificationAttribute
 from plaid.model.payment_amount import PaymentAmount
 from plaid.model.payment_amount_currency import PaymentAmountCurrency
 from plaid.model.payment_channel import PaymentChannel
@@ -409,6 +436,8 @@ from plaid.model.payment_meta import PaymentMeta
 from plaid.model.payment_schedule_interval import PaymentScheduleInterval
 from plaid.model.payment_scheme import PaymentScheme
 from plaid.model.payment_status_update_webhook import PaymentStatusUpdateWebhook
+from plaid.model.payroll_income_object import PayrollIncomeObject
+from plaid.model.payroll_item import PayrollItem
 from plaid.model.paystub import Paystub
 from plaid.model.paystub_address import PaystubAddress
 from plaid.model.paystub_deduction import PaystubDeduction
@@ -453,7 +482,6 @@ from plaid.model.recipient_bacs_nullable import RecipientBACSNullable
 from plaid.model.recurring_transaction_frequency import RecurringTransactionFrequency
 from plaid.model.relay_event import RelayEvent
 from plaid.model.removed_transaction import RemovedTransaction
-from plaid.model.requested_scopes import RequestedScopes
 from plaid.model.sandbox_bank_transfer_fire_webhook_request import SandboxBankTransferFireWebhookRequest
 from plaid.model.sandbox_bank_transfer_fire_webhook_response import SandboxBankTransferFireWebhookResponse
 from plaid.model.sandbox_bank_transfer_simulate_request import SandboxBankTransferSimulateRequest
@@ -475,6 +503,8 @@ from plaid.model.sandbox_public_token_create_request import SandboxPublicTokenCr
 from plaid.model.sandbox_public_token_create_request_options import SandboxPublicTokenCreateRequestOptions
 from plaid.model.sandbox_public_token_create_request_options_transactions import SandboxPublicTokenCreateRequestOptionsTransactions
 from plaid.model.sandbox_public_token_create_response import SandboxPublicTokenCreateResponse
+from plaid.model.sandbox_transfer_fire_webhook_request import SandboxTransferFireWebhookRequest
+from plaid.model.sandbox_transfer_fire_webhook_response import SandboxTransferFireWebhookResponse
 from plaid.model.sandbox_transfer_repayment_simulate_request import SandboxTransferRepaymentSimulateRequest
 from plaid.model.sandbox_transfer_repayment_simulate_response import SandboxTransferRepaymentSimulateResponse
 from plaid.model.sandbox_transfer_simulate_request import SandboxTransferSimulateRequest
@@ -584,6 +614,8 @@ from plaid.model.transfer_intent_status import TransferIntentStatus
 from plaid.model.transfer_list_request import TransferListRequest
 from plaid.model.transfer_list_response import TransferListResponse
 from plaid.model.transfer_metadata import TransferMetadata
+from plaid.model.transfer_migrate_account_request import TransferMigrateAccountRequest
+from plaid.model.transfer_migrate_account_response import TransferMigrateAccountResponse
 from plaid.model.transfer_network import TransferNetwork
 from plaid.model.transfer_repayment import TransferRepayment
 from plaid.model.transfer_repayment_list_request import TransferRepaymentListRequest
@@ -617,6 +649,7 @@ from plaid.model.w2_state_and_local_wages import W2StateAndLocalWages
 from plaid.model.wallet_balance import WalletBalance
 from plaid.model.wallet_get_request import WalletGetRequest
 from plaid.model.wallet_get_response import WalletGetResponse
+from plaid.model.wallet_numbers import WalletNumbers
 from plaid.model.wallet_transaction import WalletTransaction
 from plaid.model.wallet_transaction_amount import WalletTransactionAmount
 from plaid.model.wallet_transaction_counterparty import WalletTransactionCounterparty
@@ -629,6 +662,7 @@ from plaid.model.wallet_transaction_status import WalletTransactionStatus
 from plaid.model.wallet_transactions_list_request import WalletTransactionsListRequest
 from plaid.model.wallet_transactions_list_response import WalletTransactionsListResponse
 from plaid.model.warning import Warning
+from plaid.model.webhook_type import WebhookType
 from plaid.model.webhook_update_acknowledged_webhook import WebhookUpdateAcknowledgedWebhook
 from plaid.model.webhook_verification_key_get_request import WebhookVerificationKeyGetRequest
 from plaid.model.webhook_verification_key_get_response import WebhookVerificationKeyGetResponse
